==> intelliw-1.2.7-py3-none-any.whl: intelliw/utils/debug_controller.py <==
import os
import traceback
import requests
from intelliw.datasets.datasets import get_dataset
from intelliw.interface.apijob import ApiService
from intelliw.core.infer import Infer
from intelliw.core.trainer import Trainer
from intelliw.utils.logger import get_logger
from intelliw.utils.gen_model_cfg import generate_model_config_from_algorithm_config as __generate
from intelliw.config import config as iwconfig
report_addr = None
logger = get_logger()


#########################################################
#                请按照需求填写以下配置                     #
#########################################################
# (必须)设置算法文件位置（algorithms.py根目录）
PACKAGE_PATH = None

algorithm_yaml_path = os.path.join(PACKAGE_PATH, 'algorithm.yaml')
model_yaml_path = os.path.join(PACKAGE_PATH, 'model.yaml')
iwconfig.RUNNING_MODE = 'SCAFFOLDING'


# 训练测试(通过算法框架调用train)
def debug_train():
    '''(debug_train时必填)
    设置训练测试数据
    example:
        DATASET_ID = "asdasdasdasdas"   数据集id,获取途径 AI工作坊数据集管理中获取id, 不使用传入None
        TRAIN_CSV_PATH = "localcsvpath" or ["localcsvpath1", "localcsvpath2"]  本地训练csv, 如果写了DATASET_ID, 优先DATASET_ID
        DATASET_RATIO = [0.7, 0.2, 0.1] 训练/验证/测试 数据集比例, 值在0-1之间
        iwconfig.DATA_SPLIT_MODE = 0    数据集划分模式, 0 顺序划分,1 随机划分, 2 根据特征列进行划分(需要在algorithm.yaml的超参中增加targetCol,来指明特征列下标)

        TRAIN_NLP_CORPORA = "/home/xxx/xxx/"   本地训练nlp语料文件夹, 如果写了DATASET_ID, 优先DATASET_ID
        iwconfig.INPUT_DATA_SOURCE_TRAIN_TYPE = 1   语料文件类型 20-txt 21-csv 22-json
    '''
    DATASET_ID = None

    # csv
    TRAIN_CSV_PATH = None

    # nlp
    TRAIN_NLP_CORPORA = None
    iwconfig.INPUT_DATA_SOURCE_TRAIN_TYPE = 1  # 20-txt 21-csv 22-json

    DATASET_RATIO = [0.7, 0.2, 0.1]
    iwconfig.DATA_SPLIT_MODE = 1  # 0-顺序划分 1-随机划分

    iwconfig.set_dataset_config(DATASET_ID, DATASET_RATIO,
                                TRAIN_CSV_PATH, TRAIN_NLP_CORPORA)

    try:
        __generate(algorithm_yaml_path, model_yaml_path)
        trainer = Trainer(PACKAGE_PATH)
        train_data = get_dataset(iwconfig.DATASET_INFO)
        trainer.train(train_data)
    except Exception as e:
        stack_info = traceback.format_exc()
        logger.error(
            "fail to execute pipeline and stack:\n{}".format(str(stack_info)))


# 推理测试
def debug_infer():
    '''(debug_infer时必填)
    设置推理训练数据
    example: INFER_DATA = {"data":[1,2,3]}
    '''
    INFER_DATA = None
    try:
        __generate(algorithm_yaml_path, model_yaml_path)
        infer = Infer(PACKAGE_PATH)
        result = infer.infer(INFER_DATA)
        print(result)
    except Exception as e:
        stack_info = traceback.format_exc()
        logger.error(
            "fail to execute pipeline and stack:\n{}".format(str(stack_info)))


# 多api测试
def debug_router():
    '''(debug_router时必填)
    设置多api
    example:
        INFER_DATA = {"data":base64}
        ROUTER_FUNC = api_test
    '''
    INFER_DATA = None
    ROUTER_FUNC = None

    try:
        __generate(algorithm_yaml_path, model_yaml_path)
        infer = Infer(PACKAGE_PATH)
        instance = infer.pipeline.instance
        result = getattr(instance, ROUTER_FUNC)(INFER_DATA)
        print(result)
    except Exception as e:
        stack_info = traceback.format_exc()
        logger.error(
            "fail to execute pipeline and stack:\n{}".format(str(stack_info)))


# http服务测试
def debug_infer_http_server():
    # (debug_infer_http_server时必填)设置http服务测试
    SERVER_PORT = 8080

    try:
        __generate(algorithm_yaml_path, model_yaml_path)
        apiservice = ApiService(SERVER_PORT, PACKAGE_PATH, report_addr)
        apiservice.run()
    except Exception as e:
        stack_info = traceback.format_exc()
        logger.error(
            "fail to execute apiService and stack:\n{}".format(str(stack_info)))


# http接口测试
def debug_server_available():
    '''(debug_server_available时必填)
    http接口测试
    example：
        URL = "http://xxx.xxx.xxx/predict"
        METHOD = "get/post"
        INFER_DATA = {"data":base64}
    '''
    URL = "https://127.0.0.1:8888/predict"
    METHOD = "post"
    INFER_DATA = None

    resp = requests.request(METHOD, URL, json=INFER_DATA, timeout=60)
    if resp.status_code != requests.codes.ok:
        resp.raise_for_status()
    print(resp.content)


if __name__ == '__main__':
    if PACKAGE_PATH is None:
        raise FileNotFoundError("请在debug_controller.py中设置PACKAGE_PATH")
    try:
        debug_train()
        # debug_infer()
        # debug_router()
        # debug_infer_http_server()
        # debug_server_available()
    except (ImportError, TypeError) as e:
        print("\033[1;31;40m如果为debug文件错误， 请通过命令 `intelliw init_debug` 更新debug文件\033[0m")
        traceback.print_exc()

==> intelliw-1.2.9rc1-py3-none-any.whl: intelliw/utils/debug_controller.py <==
import os
import traceback
# import requests
import intelliw.utils.iuap_request as requests
from intelliw.datasets.datasets import get_dataset
from intelliw.interface.apijob import ApiService
from intelliw.core.infer import Infer
from intelliw.core.trainer import Trainer
from intelliw.utils.logger import get_logger
from intelliw.utils.gen_model_cfg import generate_model_config_from_algorithm_config as __generate
from intelliw.config import config as iwconfig
report_addr = None
logger = get_logger()


#########################################################
#                请按照需求填写以下配置                     #
#########################################################
# (必须)设置算法文件位置（algorithms.py根目录）
PACKAGE_PATH = None

algorithm_yaml_path = os.path.join(PACKAGE_PATH, 'algorithm.yaml')
model_yaml_path = os.path.join(PACKAGE_PATH, 'model.yaml')
iwconfig.RUNNING_MODE = 'SCAFFOLDING'


# 训练测试(通过算法框架调用train)
def debug_train():
    '''(debug_train时必填)
    设置训练测试数据
    example:
        DATASET_ID = "asdasdasdasdas"   数据集id,获取途径 AI工作坊数据集管理中获取id, 不使用传入None
        TRAIN_CSV_PATH = "localcsvpath" or ["localcsvpath1", "localcsvpath2"]  本地训练csv, 如果写了DATASET_ID, 优先DATASET_ID
        DATASET_RATIO = [0.7, 0.2, 0.1] 训练/验证/测试 数据集比例, 值在0-1之间
        iwconfig.DATA_SPLIT_MODE = 0    数据集划分模式, 0 顺序划分,1 随机划分, 2 根据特征列进行划分(需要在algorithm.yaml的超参中增加targetCol,来指明特征列下标)

        TRAIN_NLP_CORPORA = "/home/xxx/xxx/"   本地训练nlp语料文件夹, 如果写了DATASET_ID, 优先DATASET_ID
        iwconfig.INPUT_DATA_SOURCE_TRAIN_TYPE = 1   语料文件类型 20-txt 21-csv 22-json
    '''
    DATASET_ID = None

    # csv
    TRAIN_CSV_PATH = None

    # nlp
    TRAIN_NLP_CORPORA = None
    iwconfig.INPUT_DATA_SOURCE_TRAIN_TYPE = 1  # 20-txt 21-csv 22-json

    DATASET_RATIO = [0.7, 0.2, 0.1]
    iwconfig.DATA_SPLIT_MODE = 1  # 0-顺序划分 1-随机划分

    iwconfig.set_dataset_config(DATASET_ID, DATASET_RATIO,
                                TRAIN_CSV_PATH, TRAIN_NLP_CORPORA)

    try:
        __generate(algorithm_yaml_path, model_yaml_path)
        trainer = Trainer(PACKAGE_PATH)
        train_data = get_dataset(iwconfig.DATASET_INFO)
        trainer.train(train_data)
    except Exception as e:
        stack_info = traceback.format_exc()
        logger.error(
            "fail to execute pipeline and stack:\n{}".format(str(stack_info)))


# 推理测试
def debug_infer():
    '''(debug_infer时必填)
    设置推理训练数据
    example: INFER_DATA = {"data":[1,2,3]}
    '''
    INFER_DATA = None
    try:
        __generate(algorithm_yaml_path, model_yaml_path)
        infer = Infer(PACKAGE_PATH)
        result = infer.infer(INFER_DATA)
        print(result)
    except Exception as e:
        stack_info = traceback.format_exc()
        logger.error(
            "fail to execute pipeline and stack:\n{}".format(str(stack_info)))


# 多api测试
def debug_router():
    '''(debug_router时必填)
    设置多api
    example:
        INFER_DATA = {"data":base64}
        ROUTER_FUNC = api_test
    '''
    INFER_DATA = None
    ROUTER_FUNC = None

    try:
        __generate(algorithm_yaml_path, model_yaml_path)
        infer = Infer(PACKAGE_PATH)
        instance = infer.pipeline.instance
        result = getattr(instance, ROUTER_FUNC)(INFER_DATA)
        print(result)
    except Exception as e:
        stack_info = traceback.format_exc()
        logger.error(
            "fail to execute pipeline and stack:\n{}".format(str(stack_info)))


# http服务测试
def debug_infer_http_server():
    # (debug_infer_http_server时必填)设置http服务测试
    SERVER_PORT = 8080

    try:
        __generate(algorithm_yaml_path, model_yaml_path)
        apiservice = ApiService(SERVER_PORT, PACKAGE_PATH, report_addr)
        apiservice.run()
    except Exception as e:
        stack_info = traceback.format_exc()
        logger.error(
            "fail to execute apiService and stack:\n{}".format(str(stack_info)))


# http接口测试
def debug_server_available():
    '''(debug_server_available时必填)
    http接口测试
    example：
        URL = "http://xxx.xxx.xxx/predict"
        METHOD = "get/post"
        INFER_DATA = {"data":base64}
    '''
    URL = "https://127.0.0.1:8888/predict"
    # METHOD = "post"
    INFER_DATA = None

    # resp = requests.request(METHOD, URL, json=INFER_DATA, timeout=60)
    resp = requests.post_json(url=URL, json=INFER_DATA, timeout=60)
    if resp.status != 200:
        resp.raise_for_status()
    print(resp.body)


if __name__ == '__main__':
    if PACKAGE_PATH is None:
        raise FileNotFoundError("请在debug_controller.py中设置PACKAGE_PATH")
    try:
        debug_train()
        # debug_infer()
        # debug_router()
        # debug_infer_http_server()
        # debug_server_available()
    except (ImportError, TypeError) as e:
        print("\033[1;31;40m如果为debug文件错误， 请通过命令 `intelliw init_debug` 更新debug文件\033[0m")
        traceback.print_exc()
